@@ -72,7 +72,7 @@ class DataItemPrivate;
    - \b editable. Holds whether the field is editable. The default property value is false.
   - \b validator. Provides validation of input text and has type QValidator or QRegExp.
   - \b password. Holds whether the input text is displayed or every character is replaced by asterisk.
-  The default property value is false. The property can be overshadow by the property 'alternatives'.
+  The default property value is false. The property can be overshadowed by the property 'alternatives'.
   - \b multiline. Holds whether the text is multiline. The default property value is false.
   The property can be overshadow by the property 'alternatives'.
   - \b mandatory. Holds whether the field is mandatory. The default property value is false.
@@ -84,6 +84,15 @@ class DataItemPrivate;
  - \b hideTitle. Holds whether the field title is hidden. The default property value is
  false.
  - \b titleAlternative. Holds alternative options of the title for user and has type LocalizedStringList.
+ - \b hidden. Holds whether the field is hidden. The default property value is false.
+
+ The items that \ref hasSubitems() "have subitems" may have the following properties:
+ - \b columns. Holds the recommended count of the columns. By default, this property contains 1.
+ Note that on some platforms the property will be ignored (for example, on mobile telephones).
+ - \b verticalSpacing. Holds spacing between fields that are laid out on top of each other. If no value
+ is set, the system settings will be used.
+ - \b horizontalSpacing. Holds spacing between fields that are laid out side by side. If no value is set,
+ the system settings will be used.
 
  Example of using \ref data() "data" attribute and dynamic properties:
  \code
@@ -103,7 +112,7 @@ class DataItemPrivate;
   item.setProperty("alternatives", qVariantFromValue(alternatives));
   root << item;
  }
- root << DataItem("image", tr("Image"), QImage(":/icons/qutim_64.png"));
+ root << DataItem("image", tr("Image"), Icon(QLatin1String("qutim")).pixmap(64));
  root << DataItem("string", tr("String"), "Text field");
  {
   DataItem item("multiline", tr("Multiline"), "Multiline");
@@ -160,7 +169,7 @@ class DataItemPrivate;
  \endcode
  \image html dataforms_groups_example.jpeg
 
- It is possible to allow user to modify subitems using allowModifySubitems(). Here is example:
+ It is possible to allow user to modify subitems using allowModifySubitems(). Here is an example:
  \code
  DataItem root("Nicks");
 
@@ -346,6 +355,7 @@ public:
 	\see property()
   */
 	void setProperty(const char *name, const QVariant &value);
+	QList<QByteArray> dynamicPropertyNames() const;
 protected:
 #ifndef Q_QDOC
 	friend class DataItemPrivate;
@@ -554,7 +564,8 @@ signals:
 	void accepted();
 	void rejected();
 	void helpRequested();
-	void clicked(const QString &name);
+	void clicked(int buttonIndex);
+	void clicked(qutim_sdk_0_3::AbstractDataForm::StandardButton standartButton);
 	/**
 	The signal is emitted when the state of the data form has been changed.
 	\see isChanged()
@@ -596,6 +607,7 @@ Q_DECLARE_OPERATORS_FOR_FLAGS(AbstractDataForm::StandardButtons);
 
 #ifndef Q_QDOC
 Q_DECLARE_METATYPE(qutim_sdk_0_3::DataItem);
+Q_DECLARE_METATYPE(QList<qutim_sdk_0_3::DataItem>);
 #endif
 
 #endif // DATAFORMS_H
